%Make the .NET Windaq File Format assembly visible to MATLAB
%The file path for Dataq.Files.Wdq.dll will vary
%depending on your OS and installation version.  
%The dll will only need to be added the first time you run the program
NET.addAssembly('C:\Program Files (x86)\DATAQ Instruments\DATAQ Instruments SDK Beta\WinDaq File Format .Net library - v2\Dataq.Files.Wdq.dll');

%Uncomment to view the methods and events of Dataq.Files.Wdq.Wdq
%methods Dataq.Files.Wdq.Wdq
%events Dataq.Files.Wdq.Wdq
%methodsview('Dataq.Files.Wdq.Wdq')
%methods('Dataq.Files.Wdq.Wdq')

%Uncomment to view the properties of Dataq.Files.Wdq.Header
%properties Dataq.Files.Wdq.Header 

%Uncomment to view the properties of Dataq.Files.Wdq.Channel
%properties Dataq.Files.Wdq.Channel 

WWBFileName = 'C:\DATAQ\SAMPLE.WDQ'; %CHANGE THIS LINE TO THE FILE PATH THAT YOU WANT TO OPEN

%Open the WWB file with the Windaq File Format .NET control
try
    [wdqRetVal,wdqReadFile] = Dataq.Files.Wdq.Wdq.OpenRead(WWBFileName);
catch ME
    disp(ME.message);
end 

%Display the file information
disp(WWBFileName);
disp(wdqReadFile.Header.SampleRate);
disp(wdqReadFile.Header.TimeStarted);
disp(wdqReadFile.Header.TimeStopped);

%Get the number of samples and channels in the file
numSamples = wdqReadFile.Header.DataSize_ / 2;
WWBChannels = wdqReadFile.Header.Channels; %Number of Channels

%Set the number of rows to import
WWB_Rows = 10; %Change this to the number of rows of data you want to import
%Use the next line if you want to import the entire file
%WWB_Rows = cast(numSamples, 'double')/cast(WWBChannels, 'double'); 

%Get the number of samples to import (rows * channels)
WWBSamplesSelected = WWB_Rows * double(WWBChannels);

%CHANGE THE WWBFilePosition TO YOUR DESIRED FILE LOCATION
%WWBFilePosition correlates with WinDaq Playback software's TBF value
%(Time To Beginning of File)in seconds as displayed in the lower left of the
%software's display. Press "F3" to enable if the display shows "off"
WWBFilePosition = 1.032; %0 will put the file pointer at the beginning of the file

%Calculate the time pointer and file offset for the Seek method
WWBTimePointer = 1 / wdqReadFile.Header.SampleRate;
wdqFileOffset = WWBFilePosition / WWBTimePointer; 
wdqFileSeekOrigin = System.IO.SeekOrigin.Begin;

%Use the Seek method to set the desired file position 
try
    SampleLocation = wdqReadFile.Seek(wdqFileOffset, wdqFileSeekOrigin); 
catch ME
    warning('Cannot seek file position.');
    disp(ME.message);
    return; %Stop the MATLAB script and enter a valid WWB File Position
end 

%Create a .NET arrary to hold the data.
WWB_NArray = NET.createArray('System.Double',WWBSamplesSelected);

%Read samples from the file into a .NET Array
try
    wdqReadFile.ReadEu(WWB_NArray, WWBSamplesSelected);
catch ME
    disp(ME.message);
end 

%Create a MATLAB matrix DI_NewData to hold the data.
WWB_FileData = zeros(WWB_Rows,WWBChannels);

%Loop through the .NET array and fill the data into DI_NewData matrix.
%There will be a column for each channel that is enabled.
nDataPoint = 1;
for nRows = 1:WWB_Rows
    for nChns = 1:WWBChannels
        try 
            %Fill each data point into the matrix WWB_FileData
            WWB_FileData(nRows,nChns)=WWB_NArray(nDataPoint);
        catch ME
            disp(ME.message);
        end
        nDataPoint = nDataPoint + 1;
    end
end

%Display the data in the Command Window
disp(WWB_FileData)